@@ -8,7 +8,9 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudfront._jsii
+import aws_cdk.aws_cloudfront_origins._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
@@ -17,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-cloudfront-s3",
-    "1.64.1",
+    "1.71.0",
     __name__[0:-6],
-    "aws-cloudfront-s3@1.64.1.jsii.tgz",
+    "aws-cloudfront-s3@1.71.0.jsii.tgz",
 )
 
 __all__ = [
